#!/usr/bin/env node

import { generateApiClient } from './index';

// Parse command line arguments
function parseArgs(): { schemaUrl: string; outputDir: string; skipTlsVerify: boolean } {
  const args = process.argv.slice(2);
  
  if (args.length < 2) {
    console.error('Usage: g1-api-generator <schemaUrl> <outputDir> [--skip-tls-verify]');
    process.exit(1);
  }
  
  const schemaUrl = args[0];
  const outputDir = args[1];
  const skipTlsVerify = args.includes('--skip-tls-verify');
  
  return { schemaUrl, outputDir, skipTlsVerify };
}

// Main CLI function
async function main() {
  try {
    const { schemaUrl, outputDir, skipTlsVerify } = parseArgs();
    
    await generateApiClient({
      schemaUrl,
      outputDir,
      skipTlsVerify,
      runPostProcessing: true
    });
    
    process.exit(0);
  } catch (error) {
    console.error('Error:', error instanceof Error ? error.message : error);
    process.exit(1);
  }
}

// Run the CLI
main();
